==> apigateway-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/CfnApiKeyProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `AWS::ApiGateway::ApiKey`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:27:21.865Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnApiKeyProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ApiGateway::ApiKey.CustomerId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-customerid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getCustomerId();

    /**
     * `AWS::ApiGateway::ApiKey.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDescription();

    /**
     * `AWS::ApiGateway::ApiKey.Enabled`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-enabled
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getEnabled();

    /**
     * `AWS::ApiGateway::ApiKey.GenerateDistinctId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-generatedistinctid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getGenerateDistinctId();

    /**
     * `AWS::ApiGateway::ApiKey.Name`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-name
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getName();

    /**
     * `AWS::ApiGateway::ApiKey.StageKeys`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-stagekeys
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getStageKeys();

    /**
     * `AWS::ApiGateway::ApiKey.Value`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-value
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getValue();

    /**
     * @return a {@link Builder} of {@link CfnApiKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnApiKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String customerId;
        private java.lang.String description;
        private java.lang.Object enabled;
        private java.lang.Object generateDistinctId;
        private java.lang.String name;
        private java.lang.Object stageKeys;
        private java.lang.String value;

        /**
         * Sets the value of CustomerId
         * @param customerId `AWS::ApiGateway::ApiKey.CustomerId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder customerId(java.lang.String customerId) {
            this.customerId = customerId;
            return this;
        }

        /**
         * Sets the value of Description
         * @param description `AWS::ApiGateway::ApiKey.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of Enabled
         * @param enabled `AWS::ApiGateway::ApiKey.Enabled`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder enabled(java.lang.Boolean enabled) {
            this.enabled = enabled;
            return this;
        }

        /**
         * Sets the value of Enabled
         * @param enabled `AWS::ApiGateway::ApiKey.Enabled`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder enabled(software.amazon.awscdk.core.IResolvable enabled) {
            this.enabled = enabled;
            return this;
        }

        /**
         * Sets the value of GenerateDistinctId
         * @param generateDistinctId `AWS::ApiGateway::ApiKey.GenerateDistinctId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder generateDistinctId(java.lang.Boolean generateDistinctId) {
            this.generateDistinctId = generateDistinctId;
            return this;
        }

        /**
         * Sets the value of GenerateDistinctId
         * @param generateDistinctId `AWS::ApiGateway::ApiKey.GenerateDistinctId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder generateDistinctId(software.amazon.awscdk.core.IResolvable generateDistinctId) {
            this.generateDistinctId = generateDistinctId;
            return this;
        }

        /**
         * Sets the value of Name
         * @param name `AWS::ApiGateway::ApiKey.Name`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of StageKeys
         * @param stageKeys `AWS::ApiGateway::ApiKey.StageKeys`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder stageKeys(software.amazon.awscdk.core.IResolvable stageKeys) {
            this.stageKeys = stageKeys;
            return this;
        }

        /**
         * Sets the value of StageKeys
         * @param stageKeys `AWS::ApiGateway::ApiKey.StageKeys`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder stageKeys(java.util.List<java.lang.Object> stageKeys) {
            this.stageKeys = stageKeys;
            return this;
        }

        /**
         * Sets the value of Value
         * @param value `AWS::ApiGateway::ApiKey.Value`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder value(java.lang.String value) {
            this.value = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnApiKeyProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnApiKeyProps build() {
            return new Jsii$Proxy(customerId, description, enabled, generateDistinctId, name, stageKeys, value);
        }
    }

    /**
     * An implementation for {@link CfnApiKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnApiKeyProps {
        private final java.lang.String customerId;
        private final java.lang.String description;
        private final java.lang.Object enabled;
        private final java.lang.Object generateDistinctId;
        private final java.lang.String name;
        private final java.lang.Object stageKeys;
        private final java.lang.String value;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.customerId = this.jsiiGet("customerId", java.lang.String.class);
            this.description = this.jsiiGet("description", java.lang.String.class);
            this.enabled = this.jsiiGet("enabled", java.lang.Object.class);
            this.generateDistinctId = this.jsiiGet("generateDistinctId", java.lang.Object.class);
            this.name = this.jsiiGet("name", java.lang.String.class);
            this.stageKeys = this.jsiiGet("stageKeys", java.lang.Object.class);
            this.value = this.jsiiGet("value", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String customerId, java.lang.String description, java.lang.Object enabled, java.lang.Object generateDistinctId, java.lang.String name, java.lang.Object stageKeys, java.lang.String value) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.customerId = customerId;
            this.description = description;
            this.enabled = enabled;
            this.generateDistinctId = generateDistinctId;
            this.name = name;
            this.stageKeys = stageKeys;
            this.value = value;
        }

        @Override
        public java.lang.String getCustomerId() {
            return this.customerId;
        }

        @Override
        public java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public java.lang.Object getEnabled() {
            return this.enabled;
        }

        @Override
        public java.lang.Object getGenerateDistinctId() {
            return this.generateDistinctId;
        }

        @Override
        public java.lang.String getName() {
            return this.name;
        }

        @Override
        public java.lang.Object getStageKeys() {
            return this.stageKeys;
        }

        @Override
        public java.lang.String getValue() {
            return this.value;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getCustomerId() != null) {
                obj.set("customerId", om.valueToTree(this.getCustomerId()));
            }
            if (this.getDescription() != null) {
                obj.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getEnabled() != null) {
                obj.set("enabled", om.valueToTree(this.getEnabled()));
            }
            if (this.getGenerateDistinctId() != null) {
                obj.set("generateDistinctId", om.valueToTree(this.getGenerateDistinctId()));
            }
            if (this.getName() != null) {
                obj.set("name", om.valueToTree(this.getName()));
            }
            if (this.getStageKeys() != null) {
                obj.set("stageKeys", om.valueToTree(this.getStageKeys()));
            }
            if (this.getValue() != null) {
                obj.set("value", om.valueToTree(this.getValue()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnApiKeyProps.Jsii$Proxy that = (CfnApiKeyProps.Jsii$Proxy) o;

            if (this.customerId != null ? !this.customerId.equals(that.customerId) : that.customerId != null) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            if (this.enabled != null ? !this.enabled.equals(that.enabled) : that.enabled != null) return false;
            if (this.generateDistinctId != null ? !this.generateDistinctId.equals(that.generateDistinctId) : that.generateDistinctId != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            if (this.stageKeys != null ? !this.stageKeys.equals(that.stageKeys) : that.stageKeys != null) return false;
            return this.value != null ? this.value.equals(that.value) : that.value == null;
        }

        @Override
        public int hashCode() {
            int result = this.customerId != null ? this.customerId.hashCode() : 0;
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.enabled != null ? this.enabled.hashCode() : 0);
            result = 31 * result + (this.generateDistinctId != null ? this.generateDistinctId.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.stageKeys != null ? this.stageKeys.hashCode() : 0);
            result = 31 * result + (this.value != null ? this.value.hashCode() : 0);
            return result;
        }
    }
}

==> apigateway-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/CfnApiKeyProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `AWS::ApiGateway::ApiKey`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:51.560Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.CfnApiKeyProps")
@software.amazon.jsii.Jsii.Proxy(CfnApiKeyProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnApiKeyProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ApiGateway::ApiKey.CustomerId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-customerid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.String getCustomerId() {
        return null;
    }

    /**
     * `AWS::ApiGateway::ApiKey.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.String getDescription() {
        return null;
    }

    /**
     * `AWS::ApiGateway::ApiKey.Enabled`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-enabled
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.Object getEnabled() {
        return null;
    }

    /**
     * `AWS::ApiGateway::ApiKey.GenerateDistinctId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-generatedistinctid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.Object getGenerateDistinctId() {
        return null;
    }

    /**
     * `AWS::ApiGateway::ApiKey.Name`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-name
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.String getName() {
        return null;
    }

    /**
     * `AWS::ApiGateway::ApiKey.StageKeys`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-stagekeys
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.Object getStageKeys() {
        return null;
    }

    /**
     * `AWS::ApiGateway::ApiKey.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * `AWS::ApiGateway::ApiKey.Value`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html#cfn-apigateway-apikey-value
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.String getValue() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnApiKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnApiKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String customerId;
        private java.lang.String description;
        private java.lang.Object enabled;
        private java.lang.Object generateDistinctId;
        private java.lang.String name;
        private java.lang.Object stageKeys;
        private java.util.List<software.amazon.awscdk.core.CfnTag> tags;
        private java.lang.String value;

        /**
         * Sets the value of CustomerId
         * @param customerId `AWS::ApiGateway::ApiKey.CustomerId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder customerId(java.lang.String customerId) {
            this.customerId = customerId;
            return this;
        }

        /**
         * Sets the value of Description
         * @param description `AWS::ApiGateway::ApiKey.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of Enabled
         * @param enabled `AWS::ApiGateway::ApiKey.Enabled`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder enabled(java.lang.Boolean enabled) {
            this.enabled = enabled;
            return this;
        }

        /**
         * Sets the value of Enabled
         * @param enabled `AWS::ApiGateway::ApiKey.Enabled`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder enabled(software.amazon.awscdk.core.IResolvable enabled) {
            this.enabled = enabled;
            return this;
        }

        /**
         * Sets the value of GenerateDistinctId
         * @param generateDistinctId `AWS::ApiGateway::ApiKey.GenerateDistinctId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder generateDistinctId(java.lang.Boolean generateDistinctId) {
            this.generateDistinctId = generateDistinctId;
            return this;
        }

        /**
         * Sets the value of GenerateDistinctId
         * @param generateDistinctId `AWS::ApiGateway::ApiKey.GenerateDistinctId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder generateDistinctId(software.amazon.awscdk.core.IResolvable generateDistinctId) {
            this.generateDistinctId = generateDistinctId;
            return this;
        }

        /**
         * Sets the value of Name
         * @param name `AWS::ApiGateway::ApiKey.Name`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of StageKeys
         * @param stageKeys `AWS::ApiGateway::ApiKey.StageKeys`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder stageKeys(software.amazon.awscdk.core.IResolvable stageKeys) {
            this.stageKeys = stageKeys;
            return this;
        }

        /**
         * Sets the value of StageKeys
         * @param stageKeys `AWS::ApiGateway::ApiKey.StageKeys`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder stageKeys(java.util.List<java.lang.Object> stageKeys) {
            this.stageKeys = stageKeys;
            return this;
        }

        /**
         * Sets the value of Tags
         * @param tags `AWS::ApiGateway::ApiKey.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder tags(java.util.List<software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Sets the value of Value
         * @param value `AWS::ApiGateway::ApiKey.Value`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder value(java.lang.String value) {
            this.value = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnApiKeyProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnApiKeyProps build() {
            return new Jsii$Proxy(customerId, description, enabled, generateDistinctId, name, stageKeys, tags, value);
        }
    }

    /**
     * An implementation for {@link CfnApiKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnApiKeyProps {
        private final java.lang.String customerId;
        private final java.lang.String description;
        private final java.lang.Object enabled;
        private final java.lang.Object generateDistinctId;
        private final java.lang.String name;
        private final java.lang.Object stageKeys;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;
        private final java.lang.String value;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.customerId = this.jsiiGet("customerId", java.lang.String.class);
            this.description = this.jsiiGet("description", java.lang.String.class);
            this.enabled = this.jsiiGet("enabled", java.lang.Object.class);
            this.generateDistinctId = this.jsiiGet("generateDistinctId", java.lang.Object.class);
            this.name = this.jsiiGet("name", java.lang.String.class);
            this.stageKeys = this.jsiiGet("stageKeys", java.lang.Object.class);
            this.tags = this.jsiiGet("tags", java.util.List.class);
            this.value = this.jsiiGet("value", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String customerId, final java.lang.String description, final java.lang.Object enabled, final java.lang.Object generateDistinctId, final java.lang.String name, final java.lang.Object stageKeys, final java.util.List<software.amazon.awscdk.core.CfnTag> tags, final java.lang.String value) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.customerId = customerId;
            this.description = description;
            this.enabled = enabled;
            this.generateDistinctId = generateDistinctId;
            this.name = name;
            this.stageKeys = stageKeys;
            this.tags = tags;
            this.value = value;
        }

        @Override
        public java.lang.String getCustomerId() {
            return this.customerId;
        }

        @Override
        public java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public java.lang.Object getEnabled() {
            return this.enabled;
        }

        @Override
        public java.lang.Object getGenerateDistinctId() {
            return this.generateDistinctId;
        }

        @Override
        public java.lang.String getName() {
            return this.name;
        }

        @Override
        public java.lang.Object getStageKeys() {
            return this.stageKeys;
        }

        @Override
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        public java.lang.String getValue() {
            return this.value;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCustomerId() != null) {
                data.set("customerId", om.valueToTree(this.getCustomerId()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getEnabled() != null) {
                data.set("enabled", om.valueToTree(this.getEnabled()));
            }
            if (this.getGenerateDistinctId() != null) {
                data.set("generateDistinctId", om.valueToTree(this.getGenerateDistinctId()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }
            if (this.getStageKeys() != null) {
                data.set("stageKeys", om.valueToTree(this.getStageKeys()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }
            if (this.getValue() != null) {
                data.set("value", om.valueToTree(this.getValue()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigateway.CfnApiKeyProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnApiKeyProps.Jsii$Proxy that = (CfnApiKeyProps.Jsii$Proxy) o;

            if (this.customerId != null ? !this.customerId.equals(that.customerId) : that.customerId != null) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            if (this.enabled != null ? !this.enabled.equals(that.enabled) : that.enabled != null) return false;
            if (this.generateDistinctId != null ? !this.generateDistinctId.equals(that.generateDistinctId) : that.generateDistinctId != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            if (this.stageKeys != null ? !this.stageKeys.equals(that.stageKeys) : that.stageKeys != null) return false;
            if (this.tags != null ? !this.tags.equals(that.tags) : that.tags != null) return false;
            return this.value != null ? this.value.equals(that.value) : that.value == null;
        }

        @Override
        public int hashCode() {
            int result = this.customerId != null ? this.customerId.hashCode() : 0;
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.enabled != null ? this.enabled.hashCode() : 0);
            result = 31 * result + (this.generateDistinctId != null ? this.generateDistinctId.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.stageKeys != null ? this.stageKeys.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            result = 31 * result + (this.value != null ? this.value.hashCode() : 0);
            return result;
        }
    }
}
